==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTranslator.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXTranslator;no warnings;(my (%__translation)=());sub init{(my $language
=shift (@_));if (__isGerman ($language)){main::nxrequire (((
"\x43\x6f\x6d\x6d\x6f\x6e".$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x47\x65\x72\x6d\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXGermanMessages::getGermanTranslations ());}elsif (
__isSpanish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x53\x70\x61\x6e\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXSpanishMessages::getSpanishTranslations ());}elsif (
__isFrench ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x46\x72\x65\x6e\x63\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXFrenchMessages::getFrenchTranslations ());}elsif (
__isItalian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x49\x74\x61\x6c\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXItalianMessages::getItalianTranslations ());}elsif (
__isPolish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x6c\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXPolishMessages::getPolishTranslations ());}elsif (
__isPortuguese ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x72\x74\x75\x67\x75\x65\x73\x65\x4d\x65\x73\x73\x61\x67\x65\x73"
));((%__translation)=Common::NXPortugueseMessages::getPortugueseTranslations ())
;}elsif (__isRussian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x52\x75\x73\x73\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXRussianMessages::getRussianTranslations ());}(
$Common::NXTranslator::language=$language);}sub translate{(my $message=shift (@_
));(my $result=shift (@_));(my $translation=$__translation{$message});if ((not (
defined ($translation)))){Logger::debug3 ((("\x4d\x65\x73\x73\x61\x67\x65\x20".
$message).
"\x20\x69\x73\x20\x6e\x6f\x74\x20\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x64"));
return ((0x0786+ 1548-0x0d92));}else{Logger::debug3 ((((
"\x54\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20".
$message)."\x20\x74\x6f\x20").$translation));($$result=$translation);return (
(0x1848+ 1826-0x1f69));}}sub getLanguage{if (($language ne (""))){return (
$language);}else{return (undef);}}sub __isGerman{(my $language=shift (@_));if ((
$language eq "\x64\x65\x5f\x44\x45")){return ((0x012a+ 3815-0x1010));}return (
(0x1388+ 2746-0x1e42));}sub __isSpanish{(my $language=shift (@_));if (($language
 eq "\x65\x73\x5f\x45\x53")){return ((0x01ad+ 6840-0x1c64));}return (
(0x0abd+ 2809-0x15b6));}sub __isFrench{(my $language=shift (@_));if (($language 
eq "\x66\x72\x5f\x46\x52")){return ((0x0f39+ 3508-0x1cec));}return (
(0x1c2d+  46-0x1c5b));}sub __isItalian{(my $language=shift (@_));if (($language 
eq "\x69\x74\x5f\x49\x54")){return ((0x0a27+ 2754-0x14e8));}return (
(0x05e9+ 622-0x0857));}sub __isPolish{(my $language=shift (@_));if (($language 
eq "\x70\x6c\x5f\x50\x4c")){return ((0x14a7+ 3178-0x2110));}return (
(0x1652+ 3383-0x2389));}sub __isPortuguese{(my $language=shift (@_));if ((
$language eq "\x70\x74\x5f\x50\x54")){return ((0x036f+ 8531-0x24c1));}return (
(0x003c+ 3751-0x0ee3));}sub __isRussian{(my $language=shift (@_));if (($language
 eq "\x72\x75\x5f\x52\x55")){return ((0x1f7b+ 1519-0x2569));}return (
(0x0fcb+ 5109-0x23c0));}return ((0x161b+ 3093-0x222f));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXTranslator.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package Common::NXTranslator;no warnings;(my (%__translation)=());sub init{(my $language
=shift (@_));if (__isGerman ($language)){main::nxrequire (((
"\x43\x6f\x6d\x6d\x6f\x6e".$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x47\x65\x72\x6d\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXGermanMessages::getGermanTranslations ());}elsif (
__isSpanish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x53\x70\x61\x6e\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXSpanishMessages::getSpanishTranslations ());}elsif (
__isFrench ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x46\x72\x65\x6e\x63\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXFrenchMessages::getFrenchTranslations ());}elsif (
__isItalian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x49\x74\x61\x6c\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXItalianMessages::getItalianTranslations ());}elsif (
__isPolish ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x6c\x69\x73\x68\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXPolishMessages::getPolishTranslations ());}elsif (
__isPortuguese ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x50\x6f\x72\x74\x75\x67\x75\x65\x73\x65\x4d\x65\x73\x73\x61\x67\x65\x73"
));((%__translation)=Common::NXPortugueseMessages::getPortugueseTranslations ())
;}elsif (__isRussian ($language)){main::nxrequire ((("\x43\x6f\x6d\x6d\x6f\x6e".
$GLOBAL::DIRECTORY_SLASH).
"\x4e\x58\x52\x75\x73\x73\x69\x61\x6e\x4d\x65\x73\x73\x61\x67\x65\x73"));((
%__translation)=Common::NXRussianMessages::getRussianTranslations ());}(
$Common::NXTranslator::language=$language);}sub translate{(my $message=shift (@_
));(my $result=shift (@_));(my $translation=$__translation{$message});if ((not (
defined ($translation)))){Logger::debug3 ((("\x4d\x65\x73\x73\x61\x67\x65\x20".
$message).
"\x20\x69\x73\x20\x6e\x6f\x74\x20\x74\x72\x61\x6e\x73\x6c\x61\x74\x65\x64"));
return ((0x0307+ 4659-0x153a));}else{Logger::debug3 ((((
"\x54\x72\x61\x6e\x73\x6c\x61\x74\x65\x64\x20\x6d\x65\x73\x73\x61\x67\x65\x20".
$message)."\x20\x74\x6f\x20").$translation));($$result=$translation);return (
(0x0615+ 1329-0x0b45));}}sub getLanguage{if (($language ne (""))){return (
$language);}else{return (undef);}}sub __isGerman{(my $language=shift (@_));if ((
$language eq "\x64\x65\x5f\x44\x45")){return ((0x0270+ 5663-0x188e));}return (
(0x035d+ 6609-0x1d2e));}sub __isSpanish{(my $language=shift (@_));if (($language
 eq "\x65\x73\x5f\x45\x53")){return ((0x0d2a+ 2395-0x1684));}return (
(0x06f9+ 4735-0x1978));}sub __isFrench{(my $language=shift (@_));if (($language 
eq "\x66\x72\x5f\x46\x52")){return ((0x11d0+ 4736-0x244f));}return (
(0x1101+ 1547-0x170c));}sub __isItalian{(my $language=shift (@_));if (($language
 eq "\x69\x74\x5f\x49\x54")){return ((0x1b1c+ 882-0x1e8d));}return (
(0x07b5+ 6684-0x21d1));}sub __isPolish{(my $language=shift (@_));if (($language 
eq "\x70\x6c\x5f\x50\x4c")){return ((0x126b+ 2471-0x1c11));}return (
(0x0270+ 3258-0x0f2a));}sub __isPortuguese{(my $language=shift (@_));if ((
$language eq "\x70\x74\x5f\x50\x54")){return ((0x07f1+ 3425-0x1551));}return (
(0x1198+ 3634-0x1fca));}sub __isRussian{(my $language=shift (@_));if (($language
 eq "\x72\x75\x5f\x52\x55")){return ((0x0cd6+ 3529-0x1a9e));}return (
(0x0708+ 5545-0x1cb1));}return ((0x09a8+ 4589-0x1b94));
